@@ -1,31 +1,51 @@
 from __future__ import annotations
-from inspect import isclass
-import typing as ty
-from fileformats.core.typing import Self
-from abc import ABCMeta
+
+import decimal
 import importlib
 import itertools
+import sys
+import typing as ty
+from abc import ABCMeta
+from inspect import isclass
+
+if sys.version_info >= (3, 10):
+    from typing import TypeAlias
+else:
+    from typing_extensions import TypeAlias
+
+from fileformats.core.typing import Self
+
+from .classifier import Classifier
+from .decorators import classproperty
 from .exceptions import (
     FileFormatsError,
-    FormatMismatchError,
     FormatConversionError,
+    FormatMismatchError,
     FormatRecognitionError,
 )
-from .decorators import classproperty
-from .utils import (
-    subpackages,
-    add_exc_note,
-)
 from .identification import (
-    to_mime_format_name,
-    from_mime_format_name,
     IANA_MIME_TYPE_REGISTRIES,
+    from_mime_format_name,
+    to_mime_format_name,
 )
-from .classifier import Classifier
+from .utils import add_exc_note, subpackages
 
 if ty.TYPE_CHECKING:
     from .converter_helpers import Converter
 
+FieldPrimitive: TypeAlias = ty.Union[
+    str,
+    int,
+    float,
+    bool,
+    decimal.Decimal,
+    ty.Sequence[str],
+    ty.Sequence[int],
+    ty.Sequence[float],
+    ty.Sequence[bool],
+    ty.Sequence[decimal.Decimal],
+]
+
 
 class DataType(Classifier, metaclass=ABCMeta):
     """
@@ -78,9 +98,9 @@ class DataType(Classifier, metaclass=ABCMeta):
         return itertools.chain(FileSet.all_formats, Field.all_fields)
 
     @classmethod
-    def subclasses(cls) -> ty.Generator[ty.Type[Self], None, None]:
+    def subclasses(cls, **kwargs: ty.Any) -> ty.Generator[ty.Type[Self], None, None]:
         """Iterate over all installed subclasses"""
-        for subpkg in subpackages():
+        for subpkg in subpackages(**kwargs):
             for attr_name in dir(subpkg):
                 attr = getattr(subpkg, attr_name)
                 if (
@@ -95,7 +115,7 @@ class DataType(Classifier, metaclass=ABCMeta):
     def get_converter(
         cls,
         source_format: ty.Type[DataType],
-    ) -> "Converter | None":
+    ) -> "ty.Optional[Converter]":
         if issubclass(source_format, cls):
             return None
         else:
@@ -117,7 +137,11 @@ class DataType(Classifier, metaclass=ABCMeta):
         return a MIME-like identifier, e.g. "text/plain" for fileformats.text.Plain.
         and "medimage/nifti" for fileformats.medimage.Nifti.
         """
-        return f"{cls.namespace}/{to_mime_format_name(cls.__name__)}"  # type: ignore
+        mime_like: str = cls.namespace + "/"
+        if cls.vendor:
+            mime_like += "vnd." + cls.vendor + "."
+        mime_like += to_mime_format_name(cls.__name__)  # type: ignore[attr-defined]
+        return mime_like
 
     @classmethod
     def from_mime(cls, mime_string: str) -> ty.Type[DataType]:
@@ -196,16 +220,25 @@ class DataType(Classifier, metaclass=ABCMeta):
             else:
                 klass = next(iter(matching_name))
         else:
-            class_name = from_mime_format_name(format_name)
+            # Get the path to the module to load the class from
+            if format_name.startswith("vnd."):
+                name_parts = format_name.split(".")
+                vendor = name_parts[1]
+                format_name = ".".join(name_parts[2:])
+                module_path = f"fileformats.vendor.{vendor}.{namespace}"
+            else:
+                module_path = f"fileformats.{namespace}"
+            module_path = module_path.replace("-", "_")
             try:
-                module = importlib.import_module("fileformats." + namespace)
+                module = importlib.import_module(module_path)
             except ImportError:
                 raise FormatRecognitionError(
-                    f"Did not find fileformats namespace package corresponding to {namespace} "
+                    f"Did not find fileformats namespace package at '{module_path}' "
                     f"required to interpret '{mime_string}' MIME, or MIME-like, type. "
                     f"try installing the namespace package with "
                     f"'python3 -m pip install fileformats-{namespace}'."
                 ) from None
+            class_name = from_mime_format_name(format_name)
             try:
                 klass = getattr(module, class_name)
             except AttributeError:
@@ -240,7 +273,7 @@ class DataType(Classifier, metaclass=ABCMeta):
                             ) from None
 
                     classifiers_str, classified_name = format_name.split("+")
-                    classifiers = [get_format(c) for c in classifiers_str.split(".")]
+                    classifiers = [get_format(c) for c in classifiers_str.split("..")]
                     try:
                         classified = get_format(classified_name)
                     except FormatRecognitionError as e:
@@ -260,7 +293,7 @@ class DataType(Classifier, metaclass=ABCMeta):
                     klass = classified[classifiers]  # type: ignore
                 else:
                     raise FormatRecognitionError(
-                        f"Did not find '{class_name}' class in fileformats.{namespace} "
+                        f"Did not find '{class_name}' class in {module_path} "
                         f"corresponding to MIME, or MIME-like, type {mime_string}"
                     ) from None
         if not (ty.get_origin(klass) is ty.Union or issubclass(klass, cls)):
@@ -288,6 +321,7 @@ class DataType(Classifier, metaclass=ABCMeta):
     CHECK_ANNOTATION = "__fileformats_check__"
 
 
-from .fileset import FileSet  # noqa
-from .field import Field  # noqa
 import fileformats.core.converter_helpers  # noqa
+
+from .field import Field  # noqa
+from .fileset import FileSet  # noqa
