@@ -1,9 +1,17 @@
-class FileFormatsError(RuntimeError):
+class FileFormatsError(Exception):
     "Base exception class"
 
 
-class FormatMismatchError(FileFormatsError):
-    "File formats don't match"
+class FormatDefinitionError(FileFormatsError):
+    "When the file-formats class hasn't been properly defined"
+
+
+class FormatMismatchError(TypeError, FileFormatsError):
+    "Provided paths/values do not match the specified file format"
+
+
+class UnsatisfiableCopyModeError(FileFormatsError):
+    "Error copying files"
 
 
 class FormatConversionError(FileFormatsError):
@@ -19,15 +27,15 @@ class UnconstrainedExtensionException(FileFormatsError):
 
 
 class FileFormatsExtrasError(FileFormatsError):
-    """If there is an "extras hook" in the datatype class but no methods have been
+    """If there is an "extra" hook in the datatype class but no methods have been
     registered on it"""
 
 
 class FileFormatsExtrasPkgUninstalledError(FileFormatsExtrasError):
-    """If there is an "extras hook" in the datatype class and a extras package on PyPI
+    """If there is an "extra" hook in the datatype class and a extras package on PyPI
     but it hasn't been installed"""
 
 
 class FileFormatsExtrasPkgNotCheckedError(FileFormatsExtrasError):
-    """If there is an "extras hook" in the datatype class and a extras package on PyPI
+    """If there is an "extra" hook in the datatype class and a extras package on PyPI
     but it hasn't been installed"""
