@@ -1,52 +1,69 @@
-import os
-import struct
-from enum import Enum, IntEnum
-from warnings import warn
-import inspect
-import tempfile
 import errno
-from copy import copy
-from collections import Counter
-import typing as ty
-import shutil
-from operator import itemgetter, attrgetter
-import itertools
 import functools
-from pathlib import Path
 import hashlib
+import inspect
+import itertools
 import logging
+import operator
+import os
+import shutil
+import struct
+import sys
+import tempfile
+import typing as ty
+from collections import Counter
+from copy import copy
+from enum import Enum, IntEnum
+from operator import attrgetter, itemgetter
+from pathlib import Path
+from warnings import warn
+
+if sys.version_info >= (3, 10):
+    from typing import TypeAlias
+else:
+    from typing_extensions import TypeAlias
+
 from fileformats.core.typing import Self
-from .utils import (
-    fspaths_converter,
-    import_extras_module,
-)
-from .decorators import mtime_cached_property, classproperty, VALIDATED_PROPERTY_FLAG
-from .typing import FspathsInputType, CryptoMethod, PathType
-from .sampling import SampleFileGenerator
-from .identification import (
-    to_mime_format_name,
-    IANA_MIME_TYPE_REGISTRIES,
-)
+from fileformats.core.utils import _excluded_subpackages
+
 from .classifier import Classifier
+from .datatype import DataType
+from .decorators import VALIDATED_PROPERTY_FLAG, classproperty, mtime_cached_property
 from .exceptions import (
+    FileFormatsExtrasError,
+    FileFormatsExtrasPkgNotCheckedError,
+    FileFormatsExtrasPkgUninstalledError,
+    FormatConversionError,
+    FormatDefinitionError,
     FormatMismatchError,
     UnconstrainedExtensionException,
-    FormatConversionError,
     UnsatisfiableCopyModeError,
-    FormatDefinitionError,
-    FileFormatsExtrasError,
-    FileFormatsExtrasPkgUninstalledError,
-    FileFormatsExtrasPkgNotCheckedError,
 )
-from .datatype import DataType
 from .extras import extra
 from .fs_mount_identifier import FsMountIdentifier
+from .identification import IANA_MIME_TYPE_REGISTRIES, to_mime_format_name
 from .mock import MockMixin
+from .sampling import SampleFileGenerator
+from .typing import CryptoMethod, FspathsInputType, PathType
+from .utils import fspaths_converter, import_extras_module
 
 if ty.TYPE_CHECKING:
     from .converter_helpers import Converter
 
 
+class SupportsDunderLT(ty.Protocol):
+    def __lt__(self, other: ty.Any) -> bool:
+        ...
+
+
+class SupportsDunderGT(ty.Protocol):
+    def __gt__(self, other: ty.Any) -> bool:
+        ...
+
+
+FileSetPrimitive: TypeAlias = ty.Union[os.PathLike[str], ty.Sequence[os.PathLike[str]]]
+
+
 FILE_CHUNK_LEN_DEFAULT = 8192
 
 
@@ -113,7 +130,7 @@ class FileSet(DataType):
         self._additional_fspaths()
         if metadata and not isinstance(metadata, dict):
             raise TypeError(
-                f"Fileset metadata value needs to be None or dict, not {metadata} ({self})"
+                f"FileSet metadata value needs to be None or dict, not {metadata} ({self})"
             )
         self._validate_properties()
 
@@ -514,6 +531,9 @@ class FileSet(DataType):
         ----------
         fileset : FileSet
             the file-set object to convert
+        cache_root : Path, optional
+            a directory to use for any temporary files created during the conversion,
+            by default None which will use the default Pydra cache
         **kwargs
             args to pass to customise the converter task definition
 
@@ -531,7 +551,9 @@ class FileSet(DataType):
             return copy(fileset)
         kwargs[converter.in_file] = fileset
         task = attrs.evolve(converter.task, **kwargs)
-        outputs = task()
+        # We need to use a fresh cache root each time to avoid picking up previous
+        # conversions that no longer exist
+        outputs = task(cache_root=tempfile.mkdtemp())  # type: ignore[call-arg]
         out_file = getattr(outputs, converter.out_file)
         if not isinstance(out_file, cls):
             out_file = cls(out_file)
@@ -541,7 +563,7 @@ class FileSet(DataType):
     def get_converter(
         cls,
         source_format: ty.Type[DataType],
-    ) -> "Converter | None":
+    ) -> "ty.Optional[Converter]":
         """Get a converter that converts from the source format type
         into the format specified by the class
 
@@ -571,12 +593,9 @@ class FileSet(DataType):
             return None
         # trigger loading of standard converters for target format
         converters = cls.get_converters_dict()
-        try:
-            unclassified = source_format.unclassified  # type: ignore
-        except AttributeError:
-            import_extras_module(source_format)
-        else:
-            import_extras_module(unclassified)
+        # import extras modules
+        source_format._import_extras_module()  # type: ignore[attr-defined]
+        cls._import_extras_module()
         try:
             converter = converters[source_format]
         except KeyError:
@@ -612,6 +631,15 @@ class FileSet(DataType):
             converters[source_format] = converter
         return converter
 
+    @classmethod
+    def _import_extras_module(cls) -> None:
+        try:
+            unclassified = cls.unclassified  # type: ignore
+        except AttributeError:
+            import_extras_module(cls)
+        else:
+            import_extras_module(unclassified)
+
     @classmethod
     def get_converters_dict(
         cls, klass: ty.Optional[ty.Type[DataType]] = None
@@ -632,15 +660,17 @@ class FileSet(DataType):
     @classmethod
     def convertible_from(
         cls,
-        only_namespace_parents: bool = True,
-        union_sort_key: ty.Callable[[DataType], ty.Any] = attrgetter("__name__"),
+        union_sort_key: ty.Callable[
+            [ty.Type[DataType]],
+            ty.Union[SupportsDunderLT, SupportsDunderGT],
+        ] = attrgetter("__name__"),
     ) -> ty.Type["DataType"]:
         """Union of types that can be converted to this type, including the current type.
         If there are no other types that can be converted to this type, return the current type
 
         Parameters
         ----------
-        only_namespace_parents: bool
+        include_generic: bool
             If True, only consider parent classes in the same namespace for conversion.
         union_sort_key : callable[[DataType], Any], optional
             A function used to sort the union of types. Defaults to sorting by the type name.
@@ -651,13 +681,14 @@ class FileSet(DataType):
             The type or union of types that can be converted to this type.
         """
 
-        ns = cls.namespace
         datatypes: ty.List[ty.Type[DataType]] = [cls]
-        for fformat in FileSet.subclasses():
-            if issubclass(cls, fformat) and (
-                fformat.namespace == ns or not only_namespace_parents
-            ):
-                datatypes.extend(fformat.get_converters_dict().keys())
+        cls._import_extras_module()
+        exclude_subpackages = copy(_excluded_subpackages)
+        exclude_subpackages.discard(cls.namespace)
+        for subcls in FileSet.subclasses(exclude=exclude_subpackages):
+            if issubclass(subcls, cls):
+                subcls._import_extras_module()
+                datatypes.extend(subcls.get_converters_dict().keys())
         if len(datatypes) == 1:
             return cls
         concrete_datatypes = set()
@@ -674,8 +705,8 @@ class FileSet(DataType):
         for datatype in datatypes:
             add_concrete(datatype)
         # TODO: Might want to sort datatypes in a more specific order
-        return ty.Union.__getitem__(  # pyright: ignore[reportAttributeAccessIssue]
-            tuple(sorted(concrete_datatypes, key=union_sort_key))
+        return functools.reduce(
+            operator.or_, sorted(concrete_datatypes, key=union_sort_key)
         )  # type: ignore[return-value]
 
     @classmethod
@@ -772,7 +803,7 @@ class FileSet(DataType):
         """a dictionary containing all formats by their IANA MIME type (if applicable)"""
         if cls._formats_by_iana_mime is None:
             cls._formats_by_iana_mime = {
-                f.iana_mime: f
+                f.iana_mime.lower(): f
                 for f in FileSet.all_formats
                 if f.__dict__.get("iana_mime", "")
             }
@@ -1105,7 +1136,7 @@ class FileSet(DataType):
             except FormatDefinitionError:
                 mime_like = cls.__module__ + "." + cls.__name__
             raise NotImplementedError(
-                f"File paths generated by override of Fileset.generate_sample_data() "
+                f"File paths generated by override of FileSet.generate_sample_data() "
                 f"({fspaths}) do not match '{mime_like}' file type. A more specific "
                 f"implementation is required. Reason:\n\n{e}"
             )
