@@ -1,20 +1,21 @@
-from pathlib import Path
+import logging
 import re
 import typing as ty
-import logging
-from .datatype import DataType
+from pathlib import Path
+
 import fileformats.core
-from .utils import get_optional_type
-from .decorators import validated_property, classproperty
-from .identification import to_mime_format_name
-from .converter_helpers import SubtypeVar, Converter
+
 from .classifier import Classifier
+from .converter_helpers import Converter, SubtypeVar
+from .datatype import DataType
+from .decorators import classproperty, validated_property
 from .exceptions import (
+    FormatDefinitionError,
     FormatMismatchError,
     FormatRecognitionError,
-    FormatDefinitionError,
 )
-
+from .identification import to_mime_format_name
+from .utils import get_optional_type
 
 logger = logging.getLogger("fileformats")
 
@@ -449,7 +450,7 @@ class WithClassifiers:
             if not cls.ordered_classifiers:
                 classifier_names.sort()
             classified = type(
-                f"{'_'.join(classifier_names)}__{cls.__name__}",
+                f"{'__'.join(classifier_names)}___{cls.__name__}",
                 (cls,),
                 class_attrs,
             )
@@ -713,6 +714,30 @@ class WithClassifiers:
                 namespace = None
         return namespace
 
+    @classproperty
+    def vendor(cls) -> ty.Optional[str]:
+        """The "vendor" the format belongs to under the "fileformats" umbrella
+        namespace"""
+        vendor: ty.Optional[str]
+        if cls.is_classified:
+            vendors: ty.Collection[str] = set(
+                t.vendor for t in cls.classifiers if t.vendor
+            )
+            if cls.unclassified.vendor:  # type: ignore[attr-defined]
+                vendors.add(cls.unclassified.vendor)  # type: ignore[attr-defined]
+            if not vendors:
+                return None
+            if len(vendors) == 1:
+                return next(iter(vendors))
+            msg = (
+                "Cannot create reversible MIME type for because did not find a "
+                f"common vendor between all classifiers {list(cls.classifiers)}"
+            )
+            raise FormatRecognitionError(msg + f", found:\n{list(vendors)}")
+        else:
+            vendor = super().vendor  # type: ignore[misc]
+        return vendor
+
     @classproperty  # type: ignore[arg-type]
     def type_name(cls) -> str:
         """Name of type including classifiers to be used in __repr__"""
