@@ -1,7 +1,7 @@
 from fileformats.core import __version__
-from .raster import RasterImage, Bitmap, Gif, Jpeg, Png, Tiff
-from .vector import VectorImage, Svg
+
 from .notclassifiedyet import (
+    T38,
     Aces,
     Apng,
     Avci,
@@ -39,12 +39,13 @@ from .notclassifiedyet import (
     Prs_Btif,
     Prs_Pti,
     PwgRaster,
-    Svg__Xml,
-    T38,
+    Svg___Xml,
     TiffFx,
     Webp,
     Wmf,
 )
+from .raster import Bitmap, Gif, Jpeg, Png, RasterImage, Tiff
+from .vector import Svg, VectorImage
 
 __all__ = [
     "__version__",
@@ -93,7 +94,7 @@ __all__ = [
     "Prs_Btif",
     "Prs_Pti",
     "PwgRaster",
-    "Svg__Xml",
+    "Svg___Xml",
     "T38",
     "TiffFx",
     "Webp",
