@@ -1,5 +1,6 @@
-from fileformats.generic import UnicodeFile
 from fileformats.application import InformalSchema, Xml
+from fileformats.generic import UnicodeFile
+
 from .base import Image
 
 
@@ -11,7 +12,7 @@ class Svg(InformalSchema):
     pass
 
 
-class Svg__Xml(VectorImage, Xml):
+class Svg___Xml(VectorImage, Xml):
     ext = ".svg"
     iana_mime = "image/svg+xml"
     schema = Svg  # Set Xml schema attribute
